==> haskell-monad-control-1.0.2.3-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
key: monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: ccfd06c57089143c2e021ca11cc4fff5
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.3-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh
key: monad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: fc2e4158bd77e41708d637bfd395a43f
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.6.1/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh
depends:
    base-4.12.0.0 stm-2.5.0.0 transformers-0.5.5.0
    transformers-base-0.4.5.2-IJREwika6Q09fUjnypf1lr
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
